# -*- coding: utf-8 -*-
# Generated by Django 3.0.11 on 2022-09-20 13:27

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ('django_audit_events', '0005_auto_20220215_0756'),
    ]

    operations = [
        migrations.RunSQL(
            sql='CREATE INDEX CONCURRENTLY IF NOT EXISTS '
                '"django_audit_events_auditevent_timestamp_0c865855_uniq" '
                'ON "django_audit_events_auditevent" ("timestamp");',
            reverse_sql='DROP INDEX CONCURRENTLY IF EXISTS '
                        '"django_audit_events_auditevent_timestamp_0c865855_uniq";'
        ),
    ]
